Skip to contents

Complaints data from New York City's CouncilStat

Usage

nycomplaints

Format

A data frame with 341,299 rows and 11 variables:

unique_key

character Complaint identifier.

account

character NYC Council District that created the casework, this may or not be the district that the constituent lives in.

opendate

date Date the casework is created by staff.

closedate

date Close Date is the date the casework was closed. A casework could be closed because the issue is resolved or because no further action could be taken.

complaint_type

character Broader category designated by staff for the constituent casework. complaint_type corresponds to NYC Council Legislative Committees.

descriptor

character Specific category designated by staff for the constituent casework.

zip

integer Zip code of the constituent.

borough

character Borough of the constituent.

city

character City of the constituent.

council_dist

Council District of the constituent.

community_board

Community Board of the constituent.

Details

Table: Data summary

Namenycomplaints
Number of rows341299
Number of columns11
_______________________
Column type frequency:
Date2
character9
________________________
Group variablesNone

Variable type: Date

skim_variablen_missingcomplete_rateminmaxmediann_unique
opendate01.002015-01-012025-01-092018-06-193296
closedate141420.962015-01-022025-01-092018-11-202686

Variable type: character

skim_variablen_missingcomplete_rateminmaxemptyn_uniquewhitespace
unique_key01.00121203411940
account01.00660510
complaint_type74310.983250590
descriptor205070.94156012590
zip506240.8515013700
borough630970.82513050
city355550.90149014650
council_dist602100.8241201560
community_board727720.791160990

Produced from NYC Open Data Initiative data. The dataset comes from CouncilStat, which is used by many NYC Council district offices to enter and track constituent cases that can range from issues around affordable housing, to potholes and pedestrian safety. This dataset aggregates the information that individual staff have input. However, district staffs handle a wide range of complex issues. Each offices uses the program differently, and thus records cases, differently and so comparisons between accounts may be difficult. Not all offices use the program. For more info - http://labs.council.nyc/districts/data/

Author

Kieran Healy